@@ -2,9 +2,9 @@
 #'
 #' @details
 #' The Bias is defined as \deqn{
-#'   \frac{1}{n} \sum_{i=1}^n w_i \left( t_i - r_i \right),
+#'   \frac{1}{n} \sum_{i=1}^n w_i \left( r_i - t_i \right),
 #' }{
-#'   weighted.mean(t - r, w),
+#'   weighted.mean(r - t, w),
 #' }
 #' where \eqn{w_i} are normalized sample weights.
 #' Good predictions score close to 0.
@@ -17,7 +17,7 @@
 #' @export
 bias = function(truth, response, sample_weights = NULL, ...) {
   assert_regr(truth, response = response)
-  wmean(truth - response, sample_weights)
+  wmean(response - truth, sample_weights)
 }
 
 #' @include measures.R
