@@ -2,9 +2,9 @@
 #'
 #' @details
 #' The Percent Bias is defined as \deqn{
-#'   \frac{1}{n} \sum_{i=1}^n w_i \frac{\left( t_i - r_i \right)}{\left| t_i \right|},
+#'   \frac{1}{n} \sum_{i=1}^n w_i \frac{\left( r_i - t_i \right)}{\left| t_i \right|},
 #' }{
-#'   weighted.mean((t - r) / abs(t), w),
+#'   weighted.mean((r - t) / abs(t), w),
 #' }
 #' where \eqn{w_i} are normalized sample weights.
 #' Good predictions score close to 0.
@@ -20,7 +20,7 @@ pbias = function(truth, response, sample_weights = NULL, na_value = NaN, ...) {
   if (any(abs(truth) < TOL)) {
     return(na_value)
   }
-  wmean((truth - response) / abs(truth), sample_weights)
+  wmean((response - truth) / abs(truth), sample_weights)
 }
 
 #' @include measures.R
